# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/classifieds/brand/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Classifieds\\Brand\\": "packages/classifieds/brand/src",
            "Classifieds\\Brand\\Seeders\\": "packages/classifieds/brand/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Classifieds\Brand\Providers\BrandServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Brand'  => Classifieds\Brand\Facades\Brand::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Classifieds\\Brand\\Seeders\\BrandTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Classifieds\Brand\Providers\BrandServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Classifieds\Brand\Providers\BrandServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Classifieds\Brand\Providers\BrandServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/brand/{modulename}

**User**

    http://path-to-route-folder/user/brand/{modulename}

**Public**

    http://path-to-route-folder/brands


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/brand/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/brand/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/brand/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/brand/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/brand/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/brand/{modulename}/{slug}
    METHOD: GET