<?php

namespace Classifieds\Brand\Providers;

use Illuminate\Support\ServiceProvider;
use Classifieds\Brand\Brands;

class BrandServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'brand');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'brand');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();

        $this->app->register(\Classifieds\Brand\Providers\AuthServiceProvider::class);
        $this->app->register(\Classifieds\Brand\Providers\RouteServiceProvider::class);
        // $this->app->register(\Classifieds\Brand\Providers\EventServiceProvider::class);
        // $this->app->register(\Classifieds\Brand\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('classifieds.brand', function($app)
        {
            return $this->app->make(Brands::class);
        });
    }

    /**
     * Register the bindings for the service provider.
     *
     * @return void
     */
    public function registerBindings() {
                // Bind Brand to repository
        $this->app->bind(
            'Classifieds\Brand\Interfaces\BrandRepositoryInterface',
            \Classifieds\Brand\Repositories\Eloquent\BrandRepository::class
        );
    }


    /**
     * Merges user's and brand's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'classifieds.brand'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \Classifieds\Brand\Commands\Brand::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['classifieds.brand'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('classifieds/brand.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/brand')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/brand')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
